@@ -7,14 +7,21 @@
 import inspect
 import sys
 from collections import namedtuple
-from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
+from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Union
 
 from msticpy.common.exceptions import MsticpyAzureConfigError
 from msticpy.common.wsconfig import WorkspaceConfig
 from msticpy.data import QueryProvider
-from msticpy.data.azure_data import AzureData
-from msticpy.data.query_defns import DataEnvironment
-from msticpy.sectools import GeoLiteLookup, IPStackLookup, TILookup
+
+try:
+    from msticpy.context import GeoLiteLookup, IPStackLookup, TILookup
+    from msticpy.context.azure.azure_data import AzureData
+    from msticpy.data.core.query_defns import DataEnvironment
+except ImportError:
+    # Fall back to msticpy locations prior to v2.0.0
+    from msticpy.data.azure.azure_data import AzureData
+    from msticpy.data.query_defns import DataEnvironment
+    from msticpy.sectools import GeoLiteLookup, IPStackLookup, TILookup
 
 from ._version import VERSION
 from .common import MsticnbDataProviderError, MsticnbError
@@ -32,6 +39,7 @@ class SingletonDecorator:
     -----
     Using this decorator on a class enforces the following
     behavior:
+
     - First instantiation of class will work as normal
     - Subsequent attempts with the same set/values of kwargs
       will just return the original class
@@ -102,7 +110,7 @@ class DataProviders:
             by default "AzureSentinel"
         providers : Optional[List[str]], optional
             A list of provider names to load.
-            You can add addtional query providers by including them
+            You can add additional query providers by including them
             in the `providers` list.
 
         Other Parameters
@@ -336,7 +344,7 @@ class DataProviders:
         """
         return cls._DEFAULT_PROVIDERS
 
-    def _query_prov(self, provider, provider_defn, **kwargs):
+    def _query_prov(self, provider: str, provider_defn: ProviderDefn, **kwargs) -> Any:
         try:
             # Get any keys with the provider prefix and initialize the provider
             prov_kwargs_args = self._get_provider_kwargs(provider, **kwargs)
@@ -353,25 +361,30 @@ class DataProviders:
             if not prov_connect_args and provider_defn.get_config:
                 prov_connect_args = provider_defn.get_config()
             # call the connect function
-            created_provider.connect(**prov_connect_args)
+            try:
+                created_provider.connect(**prov_connect_args)
+            except Exception as err:  # pylint: disable=broad-except
+                print(f"Connection attempt for {provider} failed.\n{err}")
             return created_provider
         except MsticpyAzureConfigError as mp_ex:
             if get_opt("verbose"):
                 print("Warning:", mp_ex.args)
             return None
 
-    def _no_connect_prov(self, provider, provider_defn, **kwargs):
+    def _no_connect_prov(
+        self, provider: str, provider_defn: ProviderDefn, **kwargs
+    ) -> Any:
         # Get the args passed to __init__ for this provider
         prov_args = self._get_provider_kwargs(provider, **kwargs)
         # If there are none and there's a config function, call that.
         if not prov_args and provider_defn.get_config:
             prov_args = provider_defn.get_config()
-        # Instatiate the provider
-        return provider_defn.prov_class(prov_args)
+        # Instantiate the provider
+        return provider_defn.prov_class(**prov_args)
 
     # Helper methods
     @staticmethod
-    def _get_provider_kwargs(prefix, **kwargs):
+    def _get_provider_kwargs(prefix: str, **kwargs) -> Dict[str, str]:
         """Return the kwargs prefixed with "prefix_"."""
         if prefix == "LogAnalytics" and any(
             key for key in kwargs if key.startswith("AzureSentinel")
@@ -389,7 +402,7 @@ class DataProviders:
         }
 
     @staticmethod
-    def _get_connect_args(func, **kwargs):
+    def _get_connect_args(func: Callable, **kwargs) -> Dict[str, str]:
         """Get the arguments required by the `connect` function."""
         connect_params = inspect.signature(func).parameters
         return {
@@ -398,7 +411,7 @@ class DataProviders:
 
     # Provider get_config functions
     @staticmethod
-    def _azsent_get_config(**kwargs):
+    def _azsent_get_config(**kwargs) -> Dict[str, str]:
         if "workspace" in kwargs:
             ws_config = WorkspaceConfig(workspace=kwargs["workspace"])
         elif "config_file" in kwargs:
