@@ -11,18 +11,26 @@ import pandas as pd
 from bokeh.models import LayoutDOM
 from IPython.display import HTML
 from msticpy.common.timespan import TimeSpan
+from msticpy.common.utility import enum_parse
 from msticpy.datamodel import entities
-from msticpy.nbtools import nbdisplay, nbwidgets
+
+try:
+    from msticpy import nbwidgets
+    from msticpy.vis.timeline import display_timeline
+except ImportError:
+    # Fall back to msticpy locations prior to v2.0.0
+    from msticpy.nbtools import nbwidgets
+    from msticpy.nbtools.nbdisplay import display_timeline
 
 from .... import nb_metadata
 from ...._version import VERSION
 from ....common import (
     MsticnbMissingParameterError,
+    df_has_data,
     nb_data_wait,
     nb_display,
     nb_markdown,
     set_text,
-    df_has_data,
 )
 from ....nblib.azsent.alert import browse_alerts
 from ....nblib.iptools import get_geoip_whois, map_ips
@@ -47,7 +55,12 @@ class AccountType(Flag):
     Office365 = auto()
     Windows = auto()
     Linux = auto()
-    Azure = AzureActiveDirectory | AzureActivity | Office365
+    Azure = (
+        AzureActiveDirectory
+        | AzureActivity
+        | Office365  # pylint:disable=unsupported-binary-operation
+    )
+    All = Azure | Windows | Linux  # pylint:disable=unsupported-binary-operation
 
     def in_list(self, acct_types: Iterable[Union["AccountType", str]]):
         """Is the current value in the `acct_types` list."""
@@ -61,10 +74,7 @@ class AccountType(Flag):
     @classmethod
     def parse(cls, name: str):
         """Try to parse string to valid account type."""
-        try:
-            return cls[name]
-        except KeyError:
-            return None
+        return enum_parse(cls, name)
 
 
 # pylint: enable=invalid-name
@@ -131,20 +141,20 @@ class AccountSummaryResult(NotebookletResult):
         super().__init__(description, timespan, notebooklet)
         self.description: str = "Account Activity Summary"
         self.account_entity: entities.Account = None
-        self.account_activity: pd.DataFrame = None
+        self.account_activity: Optional[pd.DataFrame] = None
         self.account_selector: nbwidgets.SelectItem = None
-        self.related_alerts: pd.DataFrame = None
+        self.related_alerts: Optional[pd.DataFrame] = None
         self.alert_timeline: LayoutDOM = None
-        self.related_bookmarks: pd.DataFrame = None
-        self.host_logons: pd.DataFrame = None
-        self.host_logon_summary: pd.DataFrame = None
-        self.azure_activity: pd.DataFrame = None
-        self.azure_activity_summary: pd.DataFrame = None
+        self.related_bookmarks: Optional[pd.DataFrame] = None
+        self.host_logons: Optional[pd.DataFrame] = None
+        self.host_logon_summary: Optional[pd.DataFrame] = None
+        self.azure_activity: Optional[pd.DataFrame] = None
+        self.azure_activity_summary: Optional[pd.DataFrame] = None
         self.azure_timeline_by_provider: LayoutDOM = None
         self.account_timeline_by_ip: LayoutDOM = None
         self.azure_timeline_by_operation: LayoutDOM = None
-        self.ip_summary: pd.DataFrame = None
-        self.ip_all_data: pd.DataFrame = None
+        self.ip_summary: Optional[pd.DataFrame] = None
+        self.ip_all_data: Optional[pd.DataFrame] = None
 
 
 # pylint: enable=too-few-public-methods
@@ -155,6 +165,7 @@ class AccountSummary(Notebooklet):
     Retrieves account summary for the selected account.
 
     Main operations:
+
     - Searches for matches for the account name in Active Directory,
       Windows and Linux host logs.
     - If one or more matches are found it will return a selection
@@ -267,7 +278,16 @@ class AccountSummary(Notebooklet):
         acct_index_df = _create_account_index(all_acct_dfs)
         if acct_index_df.empty:
             nb_markdown("No accounts matching that name.")
-        elif len(acct_index_df) == 1:
+        else:
+            result.account_selector = _get_account_selector(
+                qry_prov=self.query_provider,
+                all_acct_dfs=all_acct_dfs,
+                result=result,
+                timespan=timespan,
+                options=self.options,
+                geoip=self._geo_lookup,
+            )
+        if len(acct_index_df) == 1:
             # If a single account - just display directly.
             disp_func = _create_display_callback(
                 qry_prov=self.query_provider,
@@ -283,20 +303,12 @@ class AccountSummary(Notebooklet):
                 nb_display(output)
             if not self.silent:
                 self.display_alert_timeline()
-        else:
+        elif len(acct_index_df) > 1:
             # if multiple, create a selector
             nb_markdown("<hr>")
             nb_markdown(
                 "Multiple matching accounts found, select one to see details.", "large"
             )
-            result.account_selector = _get_account_selector(
-                qry_prov=self.query_provider,
-                all_acct_dfs=all_acct_dfs,
-                result=result,
-                timespan=timespan,
-                options=self.options,
-                geoip=self._geo_lookup,
-            )
             nb_display(result.account_selector)
 
         if not acct_index_df.empty:
@@ -410,22 +422,14 @@ class AccountSummary(Notebooklet):
         return None
 
     @set_text(docs=_CELL_DOCS, key="find_additional_data")
-    def get_additional_data(self) -> pd.DataFrame:
-        """
-        Find additional data for the selected account.
-
-        Returns
-        -------
-        pd.DataFrame
-            Results with expanded columns.
-
-        """
+    def get_additional_data(self):
+        """Find additional data for the selected account."""
         if not self.check_valid_result_data():
-            return
+            return None
         acct, source = self._get_selected_account()
         if not acct or not source:
             print("Please use select an account before using this method.")
-            return
+            return None
         self._last_result.host_logons = None
         self._last_result.host_logon_summary = None
         self._last_result.account_timeline_by_ip = None
@@ -456,6 +460,7 @@ class AccountSummary(Notebooklet):
                 geoip=self._geo_lookup,
             )
             nb_display(self._last_result.ip_summary)
+            return None
         if acct_type == AccountType.Windows:
             self._last_result.host_logons = _get_windows_add_activity(
                 self.query_provider, acct, self.timespan
@@ -475,6 +480,7 @@ class AccountSummary(Notebooklet):
                 geoip=self._geo_lookup,
             )
             nb_display(self._last_result.ip_summary)
+            return None
         if acct_type in [
             AccountType.AzureActiveDirectory,
             AccountType.AzureActivity,
@@ -500,6 +506,8 @@ class AccountSummary(Notebooklet):
                 geoip=self._geo_lookup,
             )
             nb_display(self._last_result.ip_summary)
+            return None
+        return None
 
     def _get_selected_account(self):
         if (
@@ -857,9 +865,9 @@ def _create_o365_account_entity(account_name, acct_activity_df, geoip):
         & (acct_activity_df["Source"] == AccountType.Office365.name)
     ]
     account_event = o365_events.iloc[0]
-    acc_entity.Name = account_event["UserPrincipalName"]
-    if "@" in account_event["UserPrincipalName"]:
-        acc_entity.UPNSuffix = account_event["UserPrincipalName"].split("@")[1]
+    acc_entity.Name = account_event["UserId"]
+    if "@" in account_event["UserId"]:
+        acc_entity.UPNSuffix = account_event["UserId"].split("@")[1]
     acc_entity.AadTenantId = account_event["TenantId"]
     acc_entity.OrganizationId = account_event["OrganizationId"]
 
@@ -911,7 +919,7 @@ def _get_related_alerts(
 
 def _get_alerts_timeline(related_alerts: pd.DataFrame, silent=True) -> LayoutDOM:
     """Return alert timeline."""
-    return nbdisplay.display_timeline(
+    return display_timeline(
         data=related_alerts,
         title="Alerts",
         source_columns=["AlertName"],
@@ -1034,7 +1042,7 @@ def _summarize_host_activity(all_logons: pd.DataFrame, ip_col="SourceIP"):
 def _create_host_timeline(
     all_logons: pd.DataFrame, ip_col="SourceIP", silent: bool = False
 ):
-    return nbdisplay.display_timeline(
+    return display_timeline(
         data=all_logons,
         group_by=ip_col,
         source_columns=["Computer", "LogonResult", "LogonType"],
@@ -1112,7 +1120,7 @@ def _create_azure_timelines(az_all_data: pd.DataFrame, silent: bool = False):
 
 
 def _plot_timeline_by_provider(az_all_data, silent=False):
-    return nbdisplay.display_timeline(
+    return display_timeline(
         data=az_all_data,
         group_by="AppResourceProvider",
         source_columns=["Operation", "IPAddress", "AppResourceProvider"],
@@ -1122,7 +1130,7 @@ def _plot_timeline_by_provider(az_all_data, silent=False):
 
 
 def _plot_timeline_by_ip(az_all_data, silent=False):
-    return nbdisplay.display_timeline(
+    return display_timeline(
         data=az_all_data,
         group_by="IPAddress",
         source_columns=[
@@ -1137,7 +1145,7 @@ def _plot_timeline_by_ip(az_all_data, silent=False):
 
 
 def _plot_timeline_by_operation(az_all_data, silent=False):
-    return nbdisplay.display_timeline(
+    return display_timeline(
         data=az_all_data,
         group_by="Operation",
         source_columns=["AppResourceProvider", "Operation", "IPAddress"],
@@ -1177,8 +1185,12 @@ def _create_ip_summary(data, ip_col, geoip):
         .pipe(
             (get_geoip_whois, "data"), geo_lookup=geoip, ip_col=ip_col
         )  # get geoip and whois
+        .drop(columns=["TimeGenerated", "Type"], errors="ignore")
         .merge(data, left_on="IpAddress", right_on=ip_col)
     )
+    for col in group_cols:
+        if col not in all_data.columns:
+            group_cols.pop(group_cols.index(col))
     ip_summary = all_data.groupby(group_cols).agg(
         Count=pd.NamedAgg("Operation", "count"),
         FirstOperation=pd.NamedAgg("TimeGenerated", "min"),
