@@ -14,9 +14,19 @@ from bokeh.plotting.figure import Figure
 from IPython.display import display
 from msticpy.common.timespan import TimeSpan
 from msticpy.datamodel import entities
-from msticpy.nbtools import foliummap, nbdisplay, nbwidgets
-from msticpy.sectools.ip_utils import get_ip_type, get_whois_df, get_whois_info
-from msticpy.sectools.tiproviders.ti_provider_base import TISeverity
+
+try:
+    from msticpy import nbwidgets
+    from msticpy.context.ip_utils import get_ip_type, get_whois_df, get_whois_info
+    from msticpy.context.tiproviders.ti_provider_base import ResultSeverity
+    from msticpy.vis import foliummap
+    from msticpy.vis.timeline import display_timeline, display_timeline_values
+except ImportError:
+    # Fall back to msticpy locations prior to v2.0.0
+    from msticpy.nbtools import foliummap, nbwidgets
+    from msticpy.nbtools.nbdisplay import display_timeline, display_timeline_values
+    from msticpy.sectools.ip_utils import get_ip_type, get_whois_df, get_whois_info
+    from msticpy.sectools.tiproviders.ti_provider_base import ResultSeverity
 
 from .... import nb_metadata
 from ...._version import VERSION
@@ -47,7 +57,7 @@ class NetworkFlowResult(NotebookletResult):
 
     Attributes
     ----------
-    host_entity : msticpy.data.nbtools.entities.Host
+    host_entity : msticpy.datamodel.entities.Host
         The host entity object contains data about the host
         such as name, environment, operating system version,
         IP addresses and Azure VM details. Depending on the
@@ -97,14 +107,14 @@ class NetworkFlowResult(NotebookletResult):
         super().__init__(description, timespan, notebooklet)
         self.description: str = "Network flow results"
         self.host_entity: entities.Host = None
-        self.network_flows: pd.DataFrame = None
+        self.network_flows: Optional[pd.DataFrame] = None
         self.plot_flows_by_protocol: Figure = None
         self.plot_flows_by_direction: Figure = None
         self.plot_flow_values: Figure = None
-        self.flow_index: pd.DataFrame = None
-        self.flow_index_data: pd.DataFrame = None
-        self.flow_summary: pd.DataFrame = None
-        self.ti_results: pd.DataFrame = None
+        self.flow_index: Optional[pd.DataFrame] = None
+        self.flow_index_data: Optional[pd.DataFrame] = None
+        self.flow_summary: Optional[pd.DataFrame] = None
+        self.ti_results: Optional[pd.DataFrame] = None
         self.geo_map: foliummap.FoliumMap = None
 
 
@@ -156,7 +166,7 @@ class NetworkFlowSummary(Notebooklet):
 
     # pylint: disable=too-many-branches
     @set_text(docs=_CELL_DOCS, key="run")  # noqa: MC0001
-    def run(
+    def run(  # noqa: MC0001
         self,
         value: Any = None,
         data: Optional[pd.DataFrame] = None,
@@ -411,7 +421,7 @@ def _get_az_net_flows(qry_prov, timespan, ip_addr, hostname):
 # Plot flows
 @set_text(docs=_CELL_DOCS, key="plot_flows_by_protocol")
 def _plot_flows_by_protocol(flow_df):
-    return nbdisplay.display_timeline(
+    return display_timeline(
         data=flow_df,
         group_by="L7Protocol",
         title="Network Flows by Protocol",
@@ -425,7 +435,7 @@ def _plot_flows_by_protocol(flow_df):
 
 @set_text(docs=_CELL_DOCS, key="plot_flows_by_direction")
 def _plot_flows_by_direction(flow_df):
-    return nbdisplay.display_timeline(
+    return display_timeline(
         data=flow_df,
         group_by="FlowDirection",
         title="Network Flows by Direction",
@@ -441,7 +451,7 @@ def _plot_flows_by_direction(flow_df):
 # Plot flow values
 @set_text(docs=_CELL_DOCS, key="plot_flow_values")
 def _plot_flow_values(flow_df, related_alert=None):
-    return nbdisplay.display_timeline_values(
+    return display_timeline_values(
         data=flow_df,
         group_by="L7Protocol",
         source_columns=[
@@ -525,35 +535,47 @@ def _get_flow_summary(flow_index):
     nb_markdown(f"Found {num_ips} unique IP Addresses.")
 
     nb_data_wait("Whois")
-    flows_df = get_whois_df(
-        flows_df,
-        ip_column="dest",
-        asn_col="DestASN",
-        whois_col="DestASNFull",
-        show_progress=True,
-    )
-    flows_df = get_whois_df(
-        flows_df,
-        ip_column="source",
-        asn_col="SourceASN",
-        whois_col="SourceASNFull",
-        show_progress=True,
-    )
-
-    return (
-        flows_df.groupby(["DestASN", "SourceASN"])
-        .agg(
-            TotalAllowedFlows=pd.NamedAgg(column="TotalAllowedFlows", aggfunc="sum"),
-            L7Protocols=pd.NamedAgg(
-                column="L7Protocol", aggfunc=lambda x: x.unique().tolist()
-            ),
-            source_ips=pd.NamedAgg(
-                column="source", aggfunc=lambda x: x.unique().tolist()
-            ),
-            dest_ips=pd.NamedAgg(column="dest", aggfunc=lambda x: x.unique().tolist()),
+    asn_columns = []
+    if flows_df["dest"].apply(get_ip_type).unique() != ["Private"]:
+        flows_df = get_whois_df(
+            flows_df,
+            ip_column="dest",
+            asn_col="DestASN",
+            whois_col="DestASNFull",
+            show_progress=True,
         )
-        .reset_index()
-    )
+        asn_columns.append("DestASN")
+    if flows_df["source"].apply(get_ip_type).unique() != ["Private"]:
+        flows_df = get_whois_df(
+            flows_df,
+            ip_column="source",
+            asn_col="SourceASN",
+            whois_col="SourceASNFull",
+            show_progress=True,
+        )
+        asn_columns.append("SourceASN")
+
+    if isinstance(flows_df, pd.DataFrame) and not flows_df.empty:
+        return (
+            flows_df.groupby(asn_columns)
+            .agg(
+                TotalAllowedFlows=pd.NamedAgg(
+                    column="TotalAllowedFlows", aggfunc="sum"
+                ),
+                L7Protocols=pd.NamedAgg(
+                    column="L7Protocol", aggfunc=lambda x: x.unique().tolist()
+                ),
+                source_ips=pd.NamedAgg(
+                    column="source", aggfunc=lambda x: x.unique().tolist()
+                ),
+                dest_ips=pd.NamedAgg(
+                    column="dest", aggfunc=lambda x: x.unique().tolist()
+                ),
+            )
+            .reset_index()
+        )
+
+    return None
 
 
 # %%
@@ -614,8 +636,8 @@ def _get_ips_from_selected_asn(flow_sum_df, select_asn):
 @set_text(docs=_CELL_DOCS, key="lookup_ip_ti")
 def _lookup_ip_ti(flows_df, ti_lookup, selected_ips):
     def ti_check_ser_sev(severity, threshold):
-        threshold = TISeverity.parse(threshold)
-        return severity.apply(lambda x: TISeverity.parse(x) >= threshold)
+        threshold = ResultSeverity.parse(threshold)
+        return severity.apply(lambda x: ResultSeverity.parse(x) >= threshold)
 
     # Add the IoCType to save cost of inferring each item
     nb_data_wait("Threat Intelligence")
